# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator (autorest: 3.9.5, generator: @autorest/python@6.26.1)
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
# pylint: disable=wrong-import-position

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from ._patch import *  # pylint: disable=unused-wildcard-import

from ._data_sources_operations import DataSourcesOperations  # type: ignore
from ._indexers_operations import IndexersOperations  # type: ignore
from ._skillsets_operations import SkillsetsOperations  # type: ignore
from ._synonym_maps_operations import SynonymMapsOperations  # type: ignore
from ._indexes_operations import IndexesOperations  # type: ignore
from ._aliases_operations import AliasesOperations  # type: ignore
from ._search_service_client_operations import SearchServiceClientOperationsMixin  # type: ignore

from ._patch import __all__ as _patch_all
from ._patch import *
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "DataSourcesOperations",
    "IndexersOperations",
    "SkillsetsOperations",
    "SynonymMapsOperations",
    "IndexesOperations",
    "AliasesOperations",
    "SearchServiceClientOperationsMixin",
]
__all__.extend([p for p in _patch_all if p not in __all__])  # pyright: ignore
_patch_sdk()
